/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface AccessApplicationConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource. Conflicts with `zone_id`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#account_id AccessApplication#account_id}
    */
    readonly accountId?: string;
    /**
    * When set to true, users can authenticate to this application using their WARP session. When set to false this application will always require direct IdP authentication. This setting always overrides the organization setting for WARP authentication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allow_authenticate_via_warp AccessApplication#allow_authenticate_via_warp}
    */
    readonly allowAuthenticateViaWarp?: boolean | cdktf.IResolvable;
    /**
    * The identity providers selected for the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allowed_idps AccessApplication#allowed_idps}
    */
    readonly allowedIdps?: string[];
    /**
    * The logo URL of the app launcher.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#app_launcher_logo_url AccessApplication#app_launcher_logo_url}
    */
    readonly appLauncherLogoUrl?: string;
    /**
    * Option to show/hide applications in App Launcher. Defaults to `true`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#app_launcher_visible AccessApplication#app_launcher_visible}
    */
    readonly appLauncherVisible?: boolean | cdktf.IResolvable;
    /**
    * Option to skip identity provider selection if only one is configured in `allowed_idps`. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#auto_redirect_to_identity AccessApplication#auto_redirect_to_identity}
    */
    readonly autoRedirectToIdentity?: boolean | cdktf.IResolvable;
    /**
    * The background color of the app launcher.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#bg_color AccessApplication#bg_color}
    */
    readonly bgColor?: string;
    /**
    * Option that returns a custom error message when a user is denied access to the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#custom_deny_message AccessApplication#custom_deny_message}
    */
    readonly customDenyMessage?: string;
    /**
    * Option that redirects to a custom URL when a user is denied access to the application via identity based rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#custom_deny_url AccessApplication#custom_deny_url}
    */
    readonly customDenyUrl?: string;
    /**
    * Option that redirects to a custom URL when a user is denied access to the application via non identity rules.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#custom_non_identity_deny_url AccessApplication#custom_non_identity_deny_url}
    */
    readonly customNonIdentityDenyUrl?: string;
    /**
    * The custom pages selected for the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#custom_pages AccessApplication#custom_pages}
    */
    readonly customPages?: string[];
    /**
    * The primary hostname and path that Access will secure. If the app is visible in the App Launcher dashboard, this is the domain that will be displayed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#domain AccessApplication#domain}
    */
    readonly domain?: string;
    /**
    * Option to provide increased security against compromised authorization tokens and CSRF attacks by requiring an additional "binding" cookie on requests. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#enable_binding_cookie AccessApplication#enable_binding_cookie}
    */
    readonly enableBindingCookie?: boolean | cdktf.IResolvable;
    /**
    * The background color of the header bar in the app launcher.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#header_bg_color AccessApplication#header_bg_color}
    */
    readonly headerBgColor?: string;
    /**
    * Option to add the `HttpOnly` cookie flag to access tokens.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#http_only_cookie_attribute AccessApplication#http_only_cookie_attribute}
    */
    readonly httpOnlyCookieAttribute?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#id AccessApplication#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Image URL for the logo shown in the app launcher dashboard.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#logo_url AccessApplication#logo_url}
    */
    readonly logoUrl?: string;
    /**
    * Friendly name of the Access Application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name AccessApplication#name}
    */
    readonly name?: string;
    /**
    * Allows options preflight requests to bypass Access authentication and go directly to the origin. Cannot turn on if cors_headers is set. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#options_preflight_bypass AccessApplication#options_preflight_bypass}
    */
    readonly optionsPreflightBypass?: boolean | cdktf.IResolvable;
    /**
    * The policies associated with the application, in ascending order of precedence. When omitted, the application policies are not be updated. Warning: Do not use this field while you still have this application ID referenced as `application_id` in any `cloudflare_access_policy` resource, as it can result in an inconsistent state.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#policies AccessApplication#policies}
    */
    readonly policies?: string[];
    /**
    * Defines the same-site cookie setting for access tokens. Available values: `none`, `lax`, `strict`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#same_site_cookie_attribute AccessApplication#same_site_cookie_attribute}
    */
    readonly sameSiteCookieAttribute?: string;
    /**
    * List of domains that access will secure. Only present for self_hosted, vnc, and ssh applications. Always includes the value set as `domain`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#self_hosted_domains AccessApplication#self_hosted_domains}
    */
    readonly selfHostedDomains?: string[];
    /**
    * Option to return a 401 status code in service authentication rules on failed requests. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#service_auth_401_redirect AccessApplication#service_auth_401_redirect}
    */
    readonly serviceAuth401Redirect?: boolean | cdktf.IResolvable;
    /**
    * How often a user will be forced to re-authorise. Must be in the format `48h` or `2h45m`. Defaults to `24h`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#session_duration AccessApplication#session_duration}
    */
    readonly sessionDuration?: string;
    /**
    * Option to skip the authorization interstitial when using the CLI. Defaults to `false`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#skip_interstitial AccessApplication#skip_interstitial}
    */
    readonly skipInterstitial?: boolean | cdktf.IResolvable;
    /**
    * The itags associated with the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#tags AccessApplication#tags}
    */
    readonly tags?: string[];
    /**
    * The application type. Available values: `app_launcher`, `bookmark`, `biso`, `dash_sso`, `saas`, `self_hosted`, `ssh`, `vnc`, `warp`. Defaults to `self_hosted`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#type AccessApplication#type}
    */
    readonly type?: string;
    /**
    * The zone identifier to target for the resource. Conflicts with `account_id`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#zone_id AccessApplication#zone_id}
    */
    readonly zoneId?: string;
    /**
    * cors_headers block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#cors_headers AccessApplication#cors_headers}
    */
    readonly corsHeaders?: AccessApplicationCorsHeaders[] | cdktf.IResolvable;
    /**
    * footer_links block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#footer_links AccessApplication#footer_links}
    */
    readonly footerLinks?: AccessApplicationFooterLinks[] | cdktf.IResolvable;
    /**
    * landing_page_design block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#landing_page_design AccessApplication#landing_page_design}
    */
    readonly landingPageDesign?: AccessApplicationLandingPageDesign;
    /**
    * saas_app block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#saas_app AccessApplication#saas_app}
    */
    readonly saasApp?: AccessApplicationSaasApp;
    /**
    * scim_config block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#scim_config AccessApplication#scim_config}
    */
    readonly scimConfig?: AccessApplicationScimConfig;
}
export interface AccessApplicationCorsHeaders {
    /**
    * Value to determine whether all HTTP headers are exposed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allow_all_headers AccessApplication#allow_all_headers}
    */
    readonly allowAllHeaders?: boolean | cdktf.IResolvable;
    /**
    * Value to determine whether all methods are exposed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allow_all_methods AccessApplication#allow_all_methods}
    */
    readonly allowAllMethods?: boolean | cdktf.IResolvable;
    /**
    * Value to determine whether all origins are permitted to make CORS requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allow_all_origins AccessApplication#allow_all_origins}
    */
    readonly allowAllOrigins?: boolean | cdktf.IResolvable;
    /**
    * Value to determine if credentials (cookies, authorization headers, or TLS client certificates) are included with requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allow_credentials AccessApplication#allow_credentials}
    */
    readonly allowCredentials?: boolean | cdktf.IResolvable;
    /**
    * List of HTTP headers to expose via CORS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allowed_headers AccessApplication#allowed_headers}
    */
    readonly allowedHeaders?: string[];
    /**
    * List of methods to expose via CORS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allowed_methods AccessApplication#allowed_methods}
    */
    readonly allowedMethods?: string[];
    /**
    * List of origins permitted to make CORS requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allowed_origins AccessApplication#allowed_origins}
    */
    readonly allowedOrigins?: string[];
    /**
    * The maximum time a preflight request will be cached.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#max_age AccessApplication#max_age}
    */
    readonly maxAge?: number;
}
export declare function accessApplicationCorsHeadersToTerraform(struct?: AccessApplicationCorsHeaders | cdktf.IResolvable): any;
export declare function accessApplicationCorsHeadersToHclTerraform(struct?: AccessApplicationCorsHeaders | cdktf.IResolvable): any;
export declare class AccessApplicationCorsHeadersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AccessApplicationCorsHeaders | cdktf.IResolvable | undefined;
    set internalValue(value: AccessApplicationCorsHeaders | cdktf.IResolvable | undefined);
    private _allowAllHeaders?;
    get allowAllHeaders(): boolean | cdktf.IResolvable;
    set allowAllHeaders(value: boolean | cdktf.IResolvable);
    resetAllowAllHeaders(): void;
    get allowAllHeadersInput(): boolean | cdktf.IResolvable | undefined;
    private _allowAllMethods?;
    get allowAllMethods(): boolean | cdktf.IResolvable;
    set allowAllMethods(value: boolean | cdktf.IResolvable);
    resetAllowAllMethods(): void;
    get allowAllMethodsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowAllOrigins?;
    get allowAllOrigins(): boolean | cdktf.IResolvable;
    set allowAllOrigins(value: boolean | cdktf.IResolvable);
    resetAllowAllOrigins(): void;
    get allowAllOriginsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowCredentials?;
    get allowCredentials(): boolean | cdktf.IResolvable;
    set allowCredentials(value: boolean | cdktf.IResolvable);
    resetAllowCredentials(): void;
    get allowCredentialsInput(): boolean | cdktf.IResolvable | undefined;
    private _allowedHeaders?;
    get allowedHeaders(): string[];
    set allowedHeaders(value: string[]);
    resetAllowedHeaders(): void;
    get allowedHeadersInput(): string[] | undefined;
    private _allowedMethods?;
    get allowedMethods(): string[];
    set allowedMethods(value: string[]);
    resetAllowedMethods(): void;
    get allowedMethodsInput(): string[] | undefined;
    private _allowedOrigins?;
    get allowedOrigins(): string[];
    set allowedOrigins(value: string[]);
    resetAllowedOrigins(): void;
    get allowedOriginsInput(): string[] | undefined;
    private _maxAge?;
    get maxAge(): number;
    set maxAge(value: number);
    resetMaxAge(): void;
    get maxAgeInput(): number | undefined;
}
export declare class AccessApplicationCorsHeadersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AccessApplicationCorsHeaders[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AccessApplicationCorsHeadersOutputReference;
}
export interface AccessApplicationFooterLinks {
    /**
    * The name of the footer link.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name AccessApplication#name}
    */
    readonly name?: string;
    /**
    * The URL of the footer link.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#url AccessApplication#url}
    */
    readonly url?: string;
}
export declare function accessApplicationFooterLinksToTerraform(struct?: AccessApplicationFooterLinks | cdktf.IResolvable): any;
export declare function accessApplicationFooterLinksToHclTerraform(struct?: AccessApplicationFooterLinks | cdktf.IResolvable): any;
export declare class AccessApplicationFooterLinksOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AccessApplicationFooterLinks | cdktf.IResolvable | undefined;
    set internalValue(value: AccessApplicationFooterLinks | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _url?;
    get url(): string;
    set url(value: string);
    resetUrl(): void;
    get urlInput(): string | undefined;
}
export declare class AccessApplicationFooterLinksList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AccessApplicationFooterLinks[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AccessApplicationFooterLinksOutputReference;
}
export interface AccessApplicationLandingPageDesign {
    /**
    * The button color of the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#button_color AccessApplication#button_color}
    */
    readonly buttonColor?: string;
    /**
    * The button text color of the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#button_text_color AccessApplication#button_text_color}
    */
    readonly buttonTextColor?: string;
    /**
    * The URL of the image to be displayed in the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#image_url AccessApplication#image_url}
    */
    readonly imageUrl?: string;
    /**
    * The message of the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#message AccessApplication#message}
    */
    readonly message?: string;
    /**
    * The title of the landing page.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#title AccessApplication#title}
    */
    readonly title?: string;
}
export declare function accessApplicationLandingPageDesignToTerraform(struct?: AccessApplicationLandingPageDesignOutputReference | AccessApplicationLandingPageDesign): any;
export declare function accessApplicationLandingPageDesignToHclTerraform(struct?: AccessApplicationLandingPageDesignOutputReference | AccessApplicationLandingPageDesign): any;
export declare class AccessApplicationLandingPageDesignOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccessApplicationLandingPageDesign | undefined;
    set internalValue(value: AccessApplicationLandingPageDesign | undefined);
    private _buttonColor?;
    get buttonColor(): string;
    set buttonColor(value: string);
    resetButtonColor(): void;
    get buttonColorInput(): string | undefined;
    private _buttonTextColor?;
    get buttonTextColor(): string;
    set buttonTextColor(value: string);
    resetButtonTextColor(): void;
    get buttonTextColorInput(): string | undefined;
    private _imageUrl?;
    get imageUrl(): string;
    set imageUrl(value: string);
    resetImageUrl(): void;
    get imageUrlInput(): string | undefined;
    private _message?;
    get message(): string;
    set message(value: string);
    resetMessage(): void;
    get messageInput(): string | undefined;
    private _title?;
    get title(): string;
    set title(value: string);
    resetTitle(): void;
    get titleInput(): string | undefined;
}
export interface AccessApplicationSaasAppCustomAttributeSource {
    /**
    * The name of the attribute as provided by the IDP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name AccessApplication#name}
    */
    readonly name: string;
    /**
    * A mapping from IdP ID to claim name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name_by_idp AccessApplication#name_by_idp}
    */
    readonly nameByIdp?: {
        [key: string]: string;
    };
}
export declare function accessApplicationSaasAppCustomAttributeSourceToTerraform(struct?: AccessApplicationSaasAppCustomAttributeSourceOutputReference | AccessApplicationSaasAppCustomAttributeSource): any;
export declare function accessApplicationSaasAppCustomAttributeSourceToHclTerraform(struct?: AccessApplicationSaasAppCustomAttributeSourceOutputReference | AccessApplicationSaasAppCustomAttributeSource): any;
export declare class AccessApplicationSaasAppCustomAttributeSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccessApplicationSaasAppCustomAttributeSource | undefined;
    set internalValue(value: AccessApplicationSaasAppCustomAttributeSource | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nameByIdp?;
    get nameByIdp(): {
        [key: string]: string;
    };
    set nameByIdp(value: {
        [key: string]: string;
    });
    resetNameByIdp(): void;
    get nameByIdpInput(): {
        [key: string]: string;
    } | undefined;
}
export interface AccessApplicationSaasAppCustomAttribute {
    /**
    * A friendly name for the attribute as provided to the SaaS app.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#friendly_name AccessApplication#friendly_name}
    */
    readonly friendlyName?: string;
    /**
    * The name of the attribute as provided to the SaaS app.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name AccessApplication#name}
    */
    readonly name?: string;
    /**
    * A globally unique name for an identity or service provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name_format AccessApplication#name_format}
    */
    readonly nameFormat?: string;
    /**
    * True if the attribute must be always present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#required AccessApplication#required}
    */
    readonly required?: boolean | cdktf.IResolvable;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#source AccessApplication#source}
    */
    readonly source: AccessApplicationSaasAppCustomAttributeSource;
}
export declare function accessApplicationSaasAppCustomAttributeToTerraform(struct?: AccessApplicationSaasAppCustomAttribute | cdktf.IResolvable): any;
export declare function accessApplicationSaasAppCustomAttributeToHclTerraform(struct?: AccessApplicationSaasAppCustomAttribute | cdktf.IResolvable): any;
export declare class AccessApplicationSaasAppCustomAttributeOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AccessApplicationSaasAppCustomAttribute | cdktf.IResolvable | undefined;
    set internalValue(value: AccessApplicationSaasAppCustomAttribute | cdktf.IResolvable | undefined);
    private _friendlyName?;
    get friendlyName(): string;
    set friendlyName(value: string);
    resetFriendlyName(): void;
    get friendlyNameInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _nameFormat?;
    get nameFormat(): string;
    set nameFormat(value: string);
    resetNameFormat(): void;
    get nameFormatInput(): string | undefined;
    private _required?;
    get required(): boolean | cdktf.IResolvable;
    set required(value: boolean | cdktf.IResolvable);
    resetRequired(): void;
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
    private _source;
    get source(): AccessApplicationSaasAppCustomAttributeSourceOutputReference;
    putSource(value: AccessApplicationSaasAppCustomAttributeSource): void;
    get sourceInput(): AccessApplicationSaasAppCustomAttributeSource | undefined;
}
export declare class AccessApplicationSaasAppCustomAttributeList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AccessApplicationSaasAppCustomAttribute[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AccessApplicationSaasAppCustomAttributeOutputReference;
}
export interface AccessApplicationSaasAppCustomClaimSource {
    /**
    * The name of the attribute as provided by the IDP.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name AccessApplication#name}
    */
    readonly name: string;
    /**
    * A mapping from IdP ID to claim name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name_by_idp AccessApplication#name_by_idp}
    */
    readonly nameByIdp?: {
        [key: string]: string;
    };
}
export declare function accessApplicationSaasAppCustomClaimSourceToTerraform(struct?: AccessApplicationSaasAppCustomClaimSourceOutputReference | AccessApplicationSaasAppCustomClaimSource): any;
export declare function accessApplicationSaasAppCustomClaimSourceToHclTerraform(struct?: AccessApplicationSaasAppCustomClaimSourceOutputReference | AccessApplicationSaasAppCustomClaimSource): any;
export declare class AccessApplicationSaasAppCustomClaimSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccessApplicationSaasAppCustomClaimSource | undefined;
    set internalValue(value: AccessApplicationSaasAppCustomClaimSource | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nameByIdp?;
    get nameByIdp(): {
        [key: string]: string;
    };
    set nameByIdp(value: {
        [key: string]: string;
    });
    resetNameByIdp(): void;
    get nameByIdpInput(): {
        [key: string]: string;
    } | undefined;
}
export interface AccessApplicationSaasAppCustomClaim {
    /**
    * The name of the attribute as provided to the SaaS app.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name AccessApplication#name}
    */
    readonly name?: string;
    /**
    * True if the attribute must be always present.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#required AccessApplication#required}
    */
    readonly required?: boolean | cdktf.IResolvable;
    /**
    * The scope of the claim.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#scope AccessApplication#scope}
    */
    readonly scope?: string;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#source AccessApplication#source}
    */
    readonly source: AccessApplicationSaasAppCustomClaimSource;
}
export declare function accessApplicationSaasAppCustomClaimToTerraform(struct?: AccessApplicationSaasAppCustomClaim | cdktf.IResolvable): any;
export declare function accessApplicationSaasAppCustomClaimToHclTerraform(struct?: AccessApplicationSaasAppCustomClaim | cdktf.IResolvable): any;
export declare class AccessApplicationSaasAppCustomClaimOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AccessApplicationSaasAppCustomClaim | cdktf.IResolvable | undefined;
    set internalValue(value: AccessApplicationSaasAppCustomClaim | cdktf.IResolvable | undefined);
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _required?;
    get required(): boolean | cdktf.IResolvable;
    set required(value: boolean | cdktf.IResolvable);
    resetRequired(): void;
    get requiredInput(): boolean | cdktf.IResolvable | undefined;
    private _scope?;
    get scope(): string;
    set scope(value: string);
    resetScope(): void;
    get scopeInput(): string | undefined;
    private _source;
    get source(): AccessApplicationSaasAppCustomClaimSourceOutputReference;
    putSource(value: AccessApplicationSaasAppCustomClaimSource): void;
    get sourceInput(): AccessApplicationSaasAppCustomClaimSource | undefined;
}
export declare class AccessApplicationSaasAppCustomClaimList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AccessApplicationSaasAppCustomClaim[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AccessApplicationSaasAppCustomClaimOutputReference;
}
export interface AccessApplicationSaasAppHybridAndImplicitOptions {
    /**
    * If true, the authorization endpoint will return an access token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#return_access_token_from_authorization_endpoint AccessApplication#return_access_token_from_authorization_endpoint}
    */
    readonly returnAccessTokenFromAuthorizationEndpoint?: boolean | cdktf.IResolvable;
    /**
    * If true, the authorization endpoint will return an id token.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#return_id_token_from_authorization_endpoint AccessApplication#return_id_token_from_authorization_endpoint}
    */
    readonly returnIdTokenFromAuthorizationEndpoint?: boolean | cdktf.IResolvable;
}
export declare function accessApplicationSaasAppHybridAndImplicitOptionsToTerraform(struct?: AccessApplicationSaasAppHybridAndImplicitOptionsOutputReference | AccessApplicationSaasAppHybridAndImplicitOptions): any;
export declare function accessApplicationSaasAppHybridAndImplicitOptionsToHclTerraform(struct?: AccessApplicationSaasAppHybridAndImplicitOptionsOutputReference | AccessApplicationSaasAppHybridAndImplicitOptions): any;
export declare class AccessApplicationSaasAppHybridAndImplicitOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccessApplicationSaasAppHybridAndImplicitOptions | undefined;
    set internalValue(value: AccessApplicationSaasAppHybridAndImplicitOptions | undefined);
    private _returnAccessTokenFromAuthorizationEndpoint?;
    get returnAccessTokenFromAuthorizationEndpoint(): boolean | cdktf.IResolvable;
    set returnAccessTokenFromAuthorizationEndpoint(value: boolean | cdktf.IResolvable);
    resetReturnAccessTokenFromAuthorizationEndpoint(): void;
    get returnAccessTokenFromAuthorizationEndpointInput(): boolean | cdktf.IResolvable | undefined;
    private _returnIdTokenFromAuthorizationEndpoint?;
    get returnIdTokenFromAuthorizationEndpoint(): boolean | cdktf.IResolvable;
    set returnIdTokenFromAuthorizationEndpoint(value: boolean | cdktf.IResolvable);
    resetReturnIdTokenFromAuthorizationEndpoint(): void;
    get returnIdTokenFromAuthorizationEndpointInput(): boolean | cdktf.IResolvable | undefined;
}
export interface AccessApplicationSaasAppRefreshTokenOptions {
    /**
    * How long a refresh token will be valid for after creation. Valid units are `m`, `h` and `d`. Must be longer than 1m.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#lifetime AccessApplication#lifetime}
    */
    readonly lifetime?: string;
}
export declare function accessApplicationSaasAppRefreshTokenOptionsToTerraform(struct?: AccessApplicationSaasAppRefreshTokenOptions | cdktf.IResolvable): any;
export declare function accessApplicationSaasAppRefreshTokenOptionsToHclTerraform(struct?: AccessApplicationSaasAppRefreshTokenOptions | cdktf.IResolvable): any;
export declare class AccessApplicationSaasAppRefreshTokenOptionsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AccessApplicationSaasAppRefreshTokenOptions | cdktf.IResolvable | undefined;
    set internalValue(value: AccessApplicationSaasAppRefreshTokenOptions | cdktf.IResolvable | undefined);
    private _lifetime?;
    get lifetime(): string;
    set lifetime(value: string);
    resetLifetime(): void;
    get lifetimeInput(): string | undefined;
}
export declare class AccessApplicationSaasAppRefreshTokenOptionsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AccessApplicationSaasAppRefreshTokenOptions[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AccessApplicationSaasAppRefreshTokenOptionsOutputReference;
}
export interface AccessApplicationSaasApp {
    /**
    * The lifetime of the Access Token after creation. Valid units are `m` and `h`. Must be greater than or equal to 1m and less than or equal to 24h.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#access_token_lifetime AccessApplication#access_token_lifetime}
    */
    readonly accessTokenLifetime?: string;
    /**
    * Allow PKCE flow without a client secret.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#allow_pkce_without_client_secret AccessApplication#allow_pkce_without_client_secret}
    */
    readonly allowPkceWithoutClientSecret?: boolean | cdktf.IResolvable;
    /**
    * The URL where this applications tile redirects users.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#app_launcher_url AccessApplication#app_launcher_url}
    */
    readonly appLauncherUrl?: string;
    /**
    * **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#auth_type AccessApplication#auth_type}
    */
    readonly authType?: string;
    /**
    * The service provider's endpoint that is responsible for receiving and parsing a SAML assertion.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#consumer_service_url AccessApplication#consumer_service_url}
    */
    readonly consumerServiceUrl?: string;
    /**
    * The relay state used if not provided by the identity provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#default_relay_state AccessApplication#default_relay_state}
    */
    readonly defaultRelayState?: string;
    /**
    * The OIDC flows supported by this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#grant_types AccessApplication#grant_types}
    */
    readonly grantTypes?: string[];
    /**
    * A regex to filter Cloudflare groups returned in ID token and userinfo endpoint.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#group_filter_regex AccessApplication#group_filter_regex}
    */
    readonly groupFilterRegex?: string;
    /**
    * The format of the name identifier sent to the SaaS application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name_id_format AccessApplication#name_id_format}
    */
    readonly nameIdFormat?: string;
    /**
    * A [JSONata](https://jsonata.org/) expression that transforms an application's user identities into a NameID value for its SAML assertion. This expression should evaluate to a singular string. The output of this expression can override the `name_id_format` setting.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#name_id_transform_jsonata AccessApplication#name_id_transform_jsonata}
    */
    readonly nameIdTransformJsonata?: string;
    /**
    * The permitted URL's for Cloudflare to return Authorization codes and Access/ID tokens.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#redirect_uris AccessApplication#redirect_uris}
    */
    readonly redirectUris?: string[];
    /**
    * A [JSONata](https://jsonata.org/) expression that transforms an application's user identities into attribute assertions in the SAML response. The expression can transform id, email, name, and groups values. It can also transform fields listed in the saml_attributes or oidc_fields of the identity provider used to authenticate. The output of this expression must be a JSON object.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#saml_attribute_transform_jsonata AccessApplication#saml_attribute_transform_jsonata}
    */
    readonly samlAttributeTransformJsonata?: string;
    /**
    * Define the user information shared with access.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#scopes AccessApplication#scopes}
    */
    readonly scopes?: string[];
    /**
    * A globally unique name for an identity or service provider.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#sp_entity_id AccessApplication#sp_entity_id}
    */
    readonly spEntityId?: string;
    /**
    * custom_attribute block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#custom_attribute AccessApplication#custom_attribute}
    */
    readonly customAttribute?: AccessApplicationSaasAppCustomAttribute[] | cdktf.IResolvable;
    /**
    * custom_claim block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#custom_claim AccessApplication#custom_claim}
    */
    readonly customClaim?: AccessApplicationSaasAppCustomClaim[] | cdktf.IResolvable;
    /**
    * hybrid_and_implicit_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#hybrid_and_implicit_options AccessApplication#hybrid_and_implicit_options}
    */
    readonly hybridAndImplicitOptions?: AccessApplicationSaasAppHybridAndImplicitOptions;
    /**
    * refresh_token_options block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#refresh_token_options AccessApplication#refresh_token_options}
    */
    readonly refreshTokenOptions?: AccessApplicationSaasAppRefreshTokenOptions[] | cdktf.IResolvable;
}
export declare function accessApplicationSaasAppToTerraform(struct?: AccessApplicationSaasAppOutputReference | AccessApplicationSaasApp): any;
export declare function accessApplicationSaasAppToHclTerraform(struct?: AccessApplicationSaasAppOutputReference | AccessApplicationSaasApp): any;
export declare class AccessApplicationSaasAppOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccessApplicationSaasApp | undefined;
    set internalValue(value: AccessApplicationSaasApp | undefined);
    private _accessTokenLifetime?;
    get accessTokenLifetime(): string;
    set accessTokenLifetime(value: string);
    resetAccessTokenLifetime(): void;
    get accessTokenLifetimeInput(): string | undefined;
    private _allowPkceWithoutClientSecret?;
    get allowPkceWithoutClientSecret(): boolean | cdktf.IResolvable;
    set allowPkceWithoutClientSecret(value: boolean | cdktf.IResolvable);
    resetAllowPkceWithoutClientSecret(): void;
    get allowPkceWithoutClientSecretInput(): boolean | cdktf.IResolvable | undefined;
    private _appLauncherUrl?;
    get appLauncherUrl(): string;
    set appLauncherUrl(value: string);
    resetAppLauncherUrl(): void;
    get appLauncherUrlInput(): string | undefined;
    private _authType?;
    get authType(): string;
    set authType(value: string);
    resetAuthType(): void;
    get authTypeInput(): string | undefined;
    get clientId(): string;
    get clientSecret(): string;
    private _consumerServiceUrl?;
    get consumerServiceUrl(): string;
    set consumerServiceUrl(value: string);
    resetConsumerServiceUrl(): void;
    get consumerServiceUrlInput(): string | undefined;
    private _defaultRelayState?;
    get defaultRelayState(): string;
    set defaultRelayState(value: string);
    resetDefaultRelayState(): void;
    get defaultRelayStateInput(): string | undefined;
    private _grantTypes?;
    get grantTypes(): string[];
    set grantTypes(value: string[]);
    resetGrantTypes(): void;
    get grantTypesInput(): string[] | undefined;
    private _groupFilterRegex?;
    get groupFilterRegex(): string;
    set groupFilterRegex(value: string);
    resetGroupFilterRegex(): void;
    get groupFilterRegexInput(): string | undefined;
    get idpEntityId(): string;
    private _nameIdFormat?;
    get nameIdFormat(): string;
    set nameIdFormat(value: string);
    resetNameIdFormat(): void;
    get nameIdFormatInput(): string | undefined;
    private _nameIdTransformJsonata?;
    get nameIdTransformJsonata(): string;
    set nameIdTransformJsonata(value: string);
    resetNameIdTransformJsonata(): void;
    get nameIdTransformJsonataInput(): string | undefined;
    get publicKey(): string;
    private _redirectUris?;
    get redirectUris(): string[];
    set redirectUris(value: string[]);
    resetRedirectUris(): void;
    get redirectUrisInput(): string[] | undefined;
    private _samlAttributeTransformJsonata?;
    get samlAttributeTransformJsonata(): string;
    set samlAttributeTransformJsonata(value: string);
    resetSamlAttributeTransformJsonata(): void;
    get samlAttributeTransformJsonataInput(): string | undefined;
    private _scopes?;
    get scopes(): string[];
    set scopes(value: string[]);
    resetScopes(): void;
    get scopesInput(): string[] | undefined;
    private _spEntityId?;
    get spEntityId(): string;
    set spEntityId(value: string);
    resetSpEntityId(): void;
    get spEntityIdInput(): string | undefined;
    get ssoEndpoint(): string;
    private _customAttribute;
    get customAttribute(): AccessApplicationSaasAppCustomAttributeList;
    putCustomAttribute(value: AccessApplicationSaasAppCustomAttribute[] | cdktf.IResolvable): void;
    resetCustomAttribute(): void;
    get customAttributeInput(): cdktf.IResolvable | AccessApplicationSaasAppCustomAttribute[] | undefined;
    private _customClaim;
    get customClaim(): AccessApplicationSaasAppCustomClaimList;
    putCustomClaim(value: AccessApplicationSaasAppCustomClaim[] | cdktf.IResolvable): void;
    resetCustomClaim(): void;
    get customClaimInput(): cdktf.IResolvable | AccessApplicationSaasAppCustomClaim[] | undefined;
    private _hybridAndImplicitOptions;
    get hybridAndImplicitOptions(): AccessApplicationSaasAppHybridAndImplicitOptionsOutputReference;
    putHybridAndImplicitOptions(value: AccessApplicationSaasAppHybridAndImplicitOptions): void;
    resetHybridAndImplicitOptions(): void;
    get hybridAndImplicitOptionsInput(): AccessApplicationSaasAppHybridAndImplicitOptions | undefined;
    private _refreshTokenOptions;
    get refreshTokenOptions(): AccessApplicationSaasAppRefreshTokenOptionsList;
    putRefreshTokenOptions(value: AccessApplicationSaasAppRefreshTokenOptions[] | cdktf.IResolvable): void;
    resetRefreshTokenOptions(): void;
    get refreshTokenOptionsInput(): cdktf.IResolvable | AccessApplicationSaasAppRefreshTokenOptions[] | undefined;
}
export interface AccessApplicationScimConfigAuthentication {
    /**
    * URL used to generate the auth code used during token generation. Required when using `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.token_url`. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#authorization_url AccessApplication#authorization_url}
    */
    readonly authorizationUrl?: string;
    /**
    * Client ID used to authenticate when generating a token for authenticating with the remote SCIM service. Required when using `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#client_id AccessApplication#client_id}
    */
    readonly clientId?: string;
    /**
    * Secret used to authenticate when generating a token for authenticating with the remove SCIM service. Required when using `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#client_secret AccessApplication#client_secret}
    */
    readonly clientSecret?: string;
    /**
    * Required when using `scim_config.0.authentication.0.user`. Conflicts with `scim_config.0.authentication.0.token`, `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`, `scim_config.0.authentication.0.scopes`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#password AccessApplication#password}
    */
    readonly password?: string;
    /**
    * The authentication scheme to use when making SCIM requests to this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#scheme AccessApplication#scheme}
    */
    readonly scheme: string;
    /**
    * The authorization scopes to request when generating the token used to authenticate with the remove SCIM service. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#scopes AccessApplication#scopes}
    */
    readonly scopes?: string[];
    /**
    * Token used to authenticate with the remote SCIM service. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`, `scim_config.0.authentication.0.scopes`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#token AccessApplication#token}
    */
    readonly token?: string;
    /**
    * URL used to generate the token used to authenticate with the remote SCIM service. Required when using `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.client_id`. Conflicts with `scim_config.0.authentication.0.user`, `scim_config.0.authentication.0.password`, `scim_config.0.authentication.0.token`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#token_url AccessApplication#token_url}
    */
    readonly tokenUrl?: string;
    /**
    * User name used to authenticate with the remote SCIM service. Required when using `scim_config.0.authentication.0.password`. Conflicts with `scim_config.0.authentication.0.token`, `scim_config.0.authentication.0.client_id`, `scim_config.0.authentication.0.client_secret`, `scim_config.0.authentication.0.authorization_url`, `scim_config.0.authentication.0.token_url`, `scim_config.0.authentication.0.scopes`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#user AccessApplication#user}
    */
    readonly user?: string;
}
export declare function accessApplicationScimConfigAuthenticationToTerraform(struct?: AccessApplicationScimConfigAuthenticationOutputReference | AccessApplicationScimConfigAuthentication): any;
export declare function accessApplicationScimConfigAuthenticationToHclTerraform(struct?: AccessApplicationScimConfigAuthenticationOutputReference | AccessApplicationScimConfigAuthentication): any;
export declare class AccessApplicationScimConfigAuthenticationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccessApplicationScimConfigAuthentication | undefined;
    set internalValue(value: AccessApplicationScimConfigAuthentication | undefined);
    private _authorizationUrl?;
    get authorizationUrl(): string;
    set authorizationUrl(value: string);
    resetAuthorizationUrl(): void;
    get authorizationUrlInput(): string | undefined;
    private _clientId?;
    get clientId(): string;
    set clientId(value: string);
    resetClientId(): void;
    get clientIdInput(): string | undefined;
    private _clientSecret?;
    get clientSecret(): string;
    set clientSecret(value: string);
    resetClientSecret(): void;
    get clientSecretInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    resetPassword(): void;
    get passwordInput(): string | undefined;
    private _scheme?;
    get scheme(): string;
    set scheme(value: string);
    get schemeInput(): string | undefined;
    private _scopes?;
    get scopes(): string[];
    set scopes(value: string[]);
    resetScopes(): void;
    get scopesInput(): string[] | undefined;
    private _token?;
    get token(): string;
    set token(value: string);
    resetToken(): void;
    get tokenInput(): string | undefined;
    private _tokenUrl?;
    get tokenUrl(): string;
    set tokenUrl(value: string);
    resetTokenUrl(): void;
    get tokenUrlInput(): string | undefined;
    private _user?;
    get user(): string;
    set user(value: string);
    resetUser(): void;
    get userInput(): string | undefined;
}
export interface AccessApplicationScimConfigMappingsOperations {
    /**
    * Whether or not this mapping applies to create (POST) operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#create AccessApplication#create}
    */
    readonly create?: boolean | cdktf.IResolvable;
    /**
    * Whether or not this mapping applies to DELETE operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#delete AccessApplication#delete}
    */
    readonly delete?: boolean | cdktf.IResolvable;
    /**
    * Whether or not this mapping applies to update (PATCH/PUT) operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#update AccessApplication#update}
    */
    readonly update?: boolean | cdktf.IResolvable;
}
export declare function accessApplicationScimConfigMappingsOperationsToTerraform(struct?: AccessApplicationScimConfigMappingsOperationsOutputReference | AccessApplicationScimConfigMappingsOperations): any;
export declare function accessApplicationScimConfigMappingsOperationsToHclTerraform(struct?: AccessApplicationScimConfigMappingsOperationsOutputReference | AccessApplicationScimConfigMappingsOperations): any;
export declare class AccessApplicationScimConfigMappingsOperationsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccessApplicationScimConfigMappingsOperations | undefined;
    set internalValue(value: AccessApplicationScimConfigMappingsOperations | undefined);
    private _create?;
    get create(): boolean | cdktf.IResolvable;
    set create(value: boolean | cdktf.IResolvable);
    resetCreate(): void;
    get createInput(): boolean | cdktf.IResolvable | undefined;
    private _delete?;
    get delete(): boolean | cdktf.IResolvable;
    set delete(value: boolean | cdktf.IResolvable);
    resetDelete(): void;
    get deleteInput(): boolean | cdktf.IResolvable | undefined;
    private _update?;
    get update(): boolean | cdktf.IResolvable;
    set update(value: boolean | cdktf.IResolvable);
    resetUpdate(): void;
    get updateInput(): boolean | cdktf.IResolvable | undefined;
}
export interface AccessApplicationScimConfigMappings {
    /**
    * Whether or not this mapping is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#enabled AccessApplication#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * A [SCIM filter expression](https://datatracker.ietf.org/doc/html/rfc7644#section-3.4.2.2) that matches resources that should be provisioned to this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#filter AccessApplication#filter}
    */
    readonly filter?: string;
    /**
    * Which SCIM resource type this mapping applies to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#schema AccessApplication#schema}
    */
    readonly schema: string;
    /**
    * A [JSONata](https://jsonata.org/) expression that transforms the resource before provisioning it in the application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#transform_jsonata AccessApplication#transform_jsonata}
    */
    readonly transformJsonata?: string;
    /**
    * operations block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#operations AccessApplication#operations}
    */
    readonly operations?: AccessApplicationScimConfigMappingsOperations;
}
export declare function accessApplicationScimConfigMappingsToTerraform(struct?: AccessApplicationScimConfigMappings | cdktf.IResolvable): any;
export declare function accessApplicationScimConfigMappingsToHclTerraform(struct?: AccessApplicationScimConfigMappings | cdktf.IResolvable): any;
export declare class AccessApplicationScimConfigMappingsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): AccessApplicationScimConfigMappings | cdktf.IResolvable | undefined;
    set internalValue(value: AccessApplicationScimConfigMappings | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _filter?;
    get filter(): string;
    set filter(value: string);
    resetFilter(): void;
    get filterInput(): string | undefined;
    private _schema?;
    get schema(): string;
    set schema(value: string);
    get schemaInput(): string | undefined;
    private _transformJsonata?;
    get transformJsonata(): string;
    set transformJsonata(value: string);
    resetTransformJsonata(): void;
    get transformJsonataInput(): string | undefined;
    private _operations;
    get operations(): AccessApplicationScimConfigMappingsOperationsOutputReference;
    putOperations(value: AccessApplicationScimConfigMappingsOperations): void;
    resetOperations(): void;
    get operationsInput(): AccessApplicationScimConfigMappingsOperations | undefined;
}
export declare class AccessApplicationScimConfigMappingsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: AccessApplicationScimConfigMappings[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): AccessApplicationScimConfigMappingsOutputReference;
}
export interface AccessApplicationScimConfig {
    /**
    * If false, propagates DELETE requests to the target application for SCIM resources. If true, sets 'active' to false on the SCIM resource. Note: Some targets do not support DELETE operations.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#deactivate_on_delete AccessApplication#deactivate_on_delete}
    */
    readonly deactivateOnDelete?: boolean | cdktf.IResolvable;
    /**
    * Whether SCIM provisioning is turned on for this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#enabled AccessApplication#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * The UID of the IdP to use as the source for SCIM resources to provision to this application.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#idp_uid AccessApplication#idp_uid}
    */
    readonly idpUid: string;
    /**
    * The base URI for the application's SCIM-compatible API.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#remote_uri AccessApplication#remote_uri}
    */
    readonly remoteUri: string;
    /**
    * authentication block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#authentication AccessApplication#authentication}
    */
    readonly authentication?: AccessApplicationScimConfigAuthentication;
    /**
    * mappings block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#mappings AccessApplication#mappings}
    */
    readonly mappings?: AccessApplicationScimConfigMappings[] | cdktf.IResolvable;
}
export declare function accessApplicationScimConfigToTerraform(struct?: AccessApplicationScimConfigOutputReference | AccessApplicationScimConfig): any;
export declare function accessApplicationScimConfigToHclTerraform(struct?: AccessApplicationScimConfigOutputReference | AccessApplicationScimConfig): any;
export declare class AccessApplicationScimConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): AccessApplicationScimConfig | undefined;
    set internalValue(value: AccessApplicationScimConfig | undefined);
    private _deactivateOnDelete?;
    get deactivateOnDelete(): boolean | cdktf.IResolvable;
    set deactivateOnDelete(value: boolean | cdktf.IResolvable);
    resetDeactivateOnDelete(): void;
    get deactivateOnDeleteInput(): boolean | cdktf.IResolvable | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _idpUid?;
    get idpUid(): string;
    set idpUid(value: string);
    get idpUidInput(): string | undefined;
    private _remoteUri?;
    get remoteUri(): string;
    set remoteUri(value: string);
    get remoteUriInput(): string | undefined;
    private _authentication;
    get authentication(): AccessApplicationScimConfigAuthenticationOutputReference;
    putAuthentication(value: AccessApplicationScimConfigAuthentication): void;
    resetAuthentication(): void;
    get authenticationInput(): AccessApplicationScimConfigAuthentication | undefined;
    private _mappings;
    get mappings(): AccessApplicationScimConfigMappingsList;
    putMappings(value: AccessApplicationScimConfigMappings[] | cdktf.IResolvable): void;
    resetMappings(): void;
    get mappingsInput(): cdktf.IResolvable | AccessApplicationScimConfigMappings[] | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application cloudflare_access_application}
*/
export declare class AccessApplication extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_access_application";
    /**
    * Generates CDKTF code for importing a AccessApplication resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the AccessApplication to import
    * @param importFromId The id of the existing AccessApplication that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the AccessApplication to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/access_application cloudflare_access_application} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options AccessApplicationConfig = {}
    */
    constructor(scope: Construct, id: string, config?: AccessApplicationConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    resetAccountId(): void;
    get accountIdInput(): string | undefined;
    private _allowAuthenticateViaWarp?;
    get allowAuthenticateViaWarp(): boolean | cdktf.IResolvable;
    set allowAuthenticateViaWarp(value: boolean | cdktf.IResolvable);
    resetAllowAuthenticateViaWarp(): void;
    get allowAuthenticateViaWarpInput(): boolean | cdktf.IResolvable | undefined;
    private _allowedIdps?;
    get allowedIdps(): string[];
    set allowedIdps(value: string[]);
    resetAllowedIdps(): void;
    get allowedIdpsInput(): string[] | undefined;
    private _appLauncherLogoUrl?;
    get appLauncherLogoUrl(): string;
    set appLauncherLogoUrl(value: string);
    resetAppLauncherLogoUrl(): void;
    get appLauncherLogoUrlInput(): string | undefined;
    private _appLauncherVisible?;
    get appLauncherVisible(): boolean | cdktf.IResolvable;
    set appLauncherVisible(value: boolean | cdktf.IResolvable);
    resetAppLauncherVisible(): void;
    get appLauncherVisibleInput(): boolean | cdktf.IResolvable | undefined;
    get aud(): string;
    private _autoRedirectToIdentity?;
    get autoRedirectToIdentity(): boolean | cdktf.IResolvable;
    set autoRedirectToIdentity(value: boolean | cdktf.IResolvable);
    resetAutoRedirectToIdentity(): void;
    get autoRedirectToIdentityInput(): boolean | cdktf.IResolvable | undefined;
    private _bgColor?;
    get bgColor(): string;
    set bgColor(value: string);
    resetBgColor(): void;
    get bgColorInput(): string | undefined;
    private _customDenyMessage?;
    get customDenyMessage(): string;
    set customDenyMessage(value: string);
    resetCustomDenyMessage(): void;
    get customDenyMessageInput(): string | undefined;
    private _customDenyUrl?;
    get customDenyUrl(): string;
    set customDenyUrl(value: string);
    resetCustomDenyUrl(): void;
    get customDenyUrlInput(): string | undefined;
    private _customNonIdentityDenyUrl?;
    get customNonIdentityDenyUrl(): string;
    set customNonIdentityDenyUrl(value: string);
    resetCustomNonIdentityDenyUrl(): void;
    get customNonIdentityDenyUrlInput(): string | undefined;
    private _customPages?;
    get customPages(): string[];
    set customPages(value: string[]);
    resetCustomPages(): void;
    get customPagesInput(): string[] | undefined;
    private _domain?;
    get domain(): string;
    set domain(value: string);
    resetDomain(): void;
    get domainInput(): string | undefined;
    private _enableBindingCookie?;
    get enableBindingCookie(): boolean | cdktf.IResolvable;
    set enableBindingCookie(value: boolean | cdktf.IResolvable);
    resetEnableBindingCookie(): void;
    get enableBindingCookieInput(): boolean | cdktf.IResolvable | undefined;
    private _headerBgColor?;
    get headerBgColor(): string;
    set headerBgColor(value: string);
    resetHeaderBgColor(): void;
    get headerBgColorInput(): string | undefined;
    private _httpOnlyCookieAttribute?;
    get httpOnlyCookieAttribute(): boolean | cdktf.IResolvable;
    set httpOnlyCookieAttribute(value: boolean | cdktf.IResolvable);
    resetHttpOnlyCookieAttribute(): void;
    get httpOnlyCookieAttributeInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _logoUrl?;
    get logoUrl(): string;
    set logoUrl(value: string);
    resetLogoUrl(): void;
    get logoUrlInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
    private _optionsPreflightBypass?;
    get optionsPreflightBypass(): boolean | cdktf.IResolvable;
    set optionsPreflightBypass(value: boolean | cdktf.IResolvable);
    resetOptionsPreflightBypass(): void;
    get optionsPreflightBypassInput(): boolean | cdktf.IResolvable | undefined;
    private _policies?;
    get policies(): string[];
    set policies(value: string[]);
    resetPolicies(): void;
    get policiesInput(): string[] | undefined;
    private _sameSiteCookieAttribute?;
    get sameSiteCookieAttribute(): string;
    set sameSiteCookieAttribute(value: string);
    resetSameSiteCookieAttribute(): void;
    get sameSiteCookieAttributeInput(): string | undefined;
    private _selfHostedDomains?;
    get selfHostedDomains(): string[];
    set selfHostedDomains(value: string[]);
    resetSelfHostedDomains(): void;
    get selfHostedDomainsInput(): string[] | undefined;
    private _serviceAuth401Redirect?;
    get serviceAuth401Redirect(): boolean | cdktf.IResolvable;
    set serviceAuth401Redirect(value: boolean | cdktf.IResolvable);
    resetServiceAuth401Redirect(): void;
    get serviceAuth401RedirectInput(): boolean | cdktf.IResolvable | undefined;
    private _sessionDuration?;
    get sessionDuration(): string;
    set sessionDuration(value: string);
    resetSessionDuration(): void;
    get sessionDurationInput(): string | undefined;
    private _skipInterstitial?;
    get skipInterstitial(): boolean | cdktf.IResolvable;
    set skipInterstitial(value: boolean | cdktf.IResolvable);
    resetSkipInterstitial(): void;
    get skipInterstitialInput(): boolean | cdktf.IResolvable | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    resetZoneId(): void;
    get zoneIdInput(): string | undefined;
    private _corsHeaders;
    get corsHeaders(): AccessApplicationCorsHeadersList;
    putCorsHeaders(value: AccessApplicationCorsHeaders[] | cdktf.IResolvable): void;
    resetCorsHeaders(): void;
    get corsHeadersInput(): cdktf.IResolvable | AccessApplicationCorsHeaders[] | undefined;
    private _footerLinks;
    get footerLinks(): AccessApplicationFooterLinksList;
    putFooterLinks(value: AccessApplicationFooterLinks[] | cdktf.IResolvable): void;
    resetFooterLinks(): void;
    get footerLinksInput(): cdktf.IResolvable | AccessApplicationFooterLinks[] | undefined;
    private _landingPageDesign;
    get landingPageDesign(): AccessApplicationLandingPageDesignOutputReference;
    putLandingPageDesign(value: AccessApplicationLandingPageDesign): void;
    resetLandingPageDesign(): void;
    get landingPageDesignInput(): AccessApplicationLandingPageDesign | undefined;
    private _saasApp;
    get saasApp(): AccessApplicationSaasAppOutputReference;
    putSaasApp(value: AccessApplicationSaasApp): void;
    resetSaasApp(): void;
    get saasAppInput(): AccessApplicationSaasApp | undefined;
    private _scimConfig;
    get scimConfig(): AccessApplicationScimConfigOutputReference;
    putScimConfig(value: AccessApplicationScimConfig): void;
    resetScimConfig(): void;
    get scimConfigInput(): AccessApplicationScimConfig | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
