/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface HyperdriveConfigConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#account_id HyperdriveConfig#account_id}
    */
    readonly accountId: string;
    /**
    * The caching details for the Hyperdrive configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#caching HyperdriveConfig#caching}
    */
    readonly caching?: HyperdriveConfigCaching;
    /**
    * The identifier of this resource. This is the hyperdrive config value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#id HyperdriveConfig#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the Hyperdrive configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#name HyperdriveConfig#name}
    */
    readonly name: string;
    /**
    * The origin details for the Hyperdrive configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#origin HyperdriveConfig#origin}
    */
    readonly origin: HyperdriveConfigOrigin;
}
export interface HyperdriveConfigCaching {
    /**
    * Disable caching for this Hyperdrive configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#disabled HyperdriveConfig#disabled}
    */
    readonly disabled?: boolean | cdktf.IResolvable;
}
export declare function hyperdriveConfigCachingToTerraform(struct?: HyperdriveConfigCaching | cdktf.IResolvable): any;
export declare function hyperdriveConfigCachingToHclTerraform(struct?: HyperdriveConfigCaching | cdktf.IResolvable): any;
export declare class HyperdriveConfigCachingOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HyperdriveConfigCaching | cdktf.IResolvable | undefined;
    set internalValue(value: HyperdriveConfigCaching | cdktf.IResolvable | undefined);
    private _disabled?;
    get disabled(): boolean | cdktf.IResolvable;
    set disabled(value: boolean | cdktf.IResolvable);
    resetDisabled(): void;
    get disabledInput(): boolean | cdktf.IResolvable | undefined;
}
export interface HyperdriveConfigOrigin {
    /**
    * The name of your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#database HyperdriveConfig#database}
    */
    readonly database: string;
    /**
    * The host (hostname or IP) of your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#host HyperdriveConfig#host}
    */
    readonly host: string;
    /**
    * The password of the Hyperdrive configuration.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#password HyperdriveConfig#password}
    */
    readonly password: string;
    /**
    * The port (default: 5432 for Postgres) of your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#port HyperdriveConfig#port}
    */
    readonly port: number;
    /**
    * Specifies the URL scheme used to connect to your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#scheme HyperdriveConfig#scheme}
    */
    readonly scheme: string;
    /**
    * The user of your origin database.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#user HyperdriveConfig#user}
    */
    readonly user: string;
}
export declare function hyperdriveConfigOriginToTerraform(struct?: HyperdriveConfigOrigin | cdktf.IResolvable): any;
export declare function hyperdriveConfigOriginToHclTerraform(struct?: HyperdriveConfigOrigin | cdktf.IResolvable): any;
export declare class HyperdriveConfigOriginOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): HyperdriveConfigOrigin | cdktf.IResolvable | undefined;
    set internalValue(value: HyperdriveConfigOrigin | cdktf.IResolvable | undefined);
    private _database?;
    get database(): string;
    set database(value: string);
    get databaseInput(): string | undefined;
    private _host?;
    get host(): string;
    set host(value: string);
    get hostInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    get passwordInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    get portInput(): number | undefined;
    private _scheme?;
    get scheme(): string;
    set scheme(value: string);
    get schemeInput(): string | undefined;
    private _user?;
    get user(): string;
    set user(value: string);
    get userInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config cloudflare_hyperdrive_config}
*/
export declare class HyperdriveConfig extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_hyperdrive_config";
    /**
    * Generates CDKTF code for importing a HyperdriveConfig resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the HyperdriveConfig to import
    * @param importFromId The id of the existing HyperdriveConfig that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the HyperdriveConfig to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/hyperdrive_config cloudflare_hyperdrive_config} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options HyperdriveConfigConfig
    */
    constructor(scope: Construct, id: string, config: HyperdriveConfigConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _caching;
    get caching(): HyperdriveConfigCachingOutputReference;
    putCaching(value: HyperdriveConfigCaching): void;
    resetCaching(): void;
    get cachingInput(): cdktf.IResolvable | HyperdriveConfigCaching | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _origin;
    get origin(): HyperdriveConfigOriginOutputReference;
    putOrigin(value: HyperdriveConfigOrigin): void;
    get originInput(): cdktf.IResolvable | HyperdriveConfigOrigin | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
