/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NotificationPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#account_id NotificationPolicy#account_id}
    */
    readonly accountId: string;
    /**
    * The event type that will trigger the dispatch of a notification. See the developer documentation for descriptions of [available alert types](https://developers.cloudflare.com/fundamentals/notifications/notification-available/). Available values: `advanced_http_alert_error`, `access_custom_certificate_expiration_type`, `advanced_ddos_attack_l4_alert`, `advanced_ddos_attack_l7_alert`, `bgp_hijack_notification`, `billing_usage_alert`, `block_notification_block_removed`, `block_notification_new_block`, `block_notification_review_rejected`, `brand_protection_alert`, `brand_protection_digest`, `clickhouse_alert_fw_anomaly`, `clickhouse_alert_fw_ent_anomaly`, `custom_ssl_certificate_event_type`, `dedicated_ssl_certificate_event_type`, `dos_attack_l4`, `dos_attack_l7`, `expiring_service_token_alert`, `failing_logpush_job_disabled_alert`, `fbm_auto_advertisement`, `fbm_dosd_attack`, `fbm_volumetric_attack`, `health_check_status_notification`, `hostname_aop_custom_certificate_expiration_type`, `http_alert_edge_error`, `http_alert_origin_error`, `incident_alert`, `load_balancing_health_alert`, `load_balancing_pool_enablement_alert`, `logo_match_alert`, `magic_tunnel_health_check_event`, `maintenance_event_notification`, `mtls_certificate_store_certificate_expiration_type`, `pages_event_alert`, `radar_notification`, `real_origin_monitoring`, `scriptmonitor_alert_new_code_change_detections`, `scriptmonitor_alert_new_hosts`, `scriptmonitor_alert_new_malicious_hosts`, `scriptmonitor_alert_new_malicious_scripts`, `scriptmonitor_alert_new_malicious_url`, `scriptmonitor_alert_new_max_length_resource_url`, `scriptmonitor_alert_new_resources`, `secondary_dns_all_primaries_failing`, `secondary_dns_primaries_failing`, `secondary_dns_zone_successfully_updated`, `secondary_dns_zone_validation_warning`, `sentinel_alert`, `stream_live_notifications`, `traffic_anomalies_alert`, `tunnel_health_event`, `tunnel_update_event`, `universal_ssl_event_type`, `web_analytics_metrics_update`, `weekly_account_overview`, `workers_alert`, `zone_aop_custom_certificate_expiration_type`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#alert_type NotificationPolicy#alert_type}
    */
    readonly alertType: string;
    /**
    * Description of the notification policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#description NotificationPolicy#description}
    */
    readonly description?: string;
    /**
    * The status of the notification policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#enabled NotificationPolicy#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#id NotificationPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The name of the notification policy.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#name NotificationPolicy#name}
    */
    readonly name: string;
    /**
    * email_integration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#email_integration NotificationPolicy#email_integration}
    */
    readonly emailIntegration?: NotificationPolicyEmailIntegration[] | cdktf.IResolvable;
    /**
    * filters block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#filters NotificationPolicy#filters}
    */
    readonly filters?: NotificationPolicyFilters;
    /**
    * pagerduty_integration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#pagerduty_integration NotificationPolicy#pagerduty_integration}
    */
    readonly pagerdutyIntegration?: NotificationPolicyPagerdutyIntegration[] | cdktf.IResolvable;
    /**
    * webhooks_integration block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#webhooks_integration NotificationPolicy#webhooks_integration}
    */
    readonly webhooksIntegration?: NotificationPolicyWebhooksIntegration[] | cdktf.IResolvable;
}
export interface NotificationPolicyEmailIntegration {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#id NotificationPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#name NotificationPolicy#name}
    */
    readonly name?: string;
}
export declare function notificationPolicyEmailIntegrationToTerraform(struct?: NotificationPolicyEmailIntegration | cdktf.IResolvable): any;
export declare function notificationPolicyEmailIntegrationToHclTerraform(struct?: NotificationPolicyEmailIntegration | cdktf.IResolvable): any;
export declare class NotificationPolicyEmailIntegrationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NotificationPolicyEmailIntegration | cdktf.IResolvable | undefined;
    set internalValue(value: NotificationPolicyEmailIntegration | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
}
export declare class NotificationPolicyEmailIntegrationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NotificationPolicyEmailIntegration[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NotificationPolicyEmailIntegrationOutputReference;
}
export interface NotificationPolicyFilters {
    /**
    * Targeted actions for alert.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#actions NotificationPolicy#actions}
    */
    readonly actions?: string[];
    /**
    * Affected components for alert. Available values: `API`, `API Shield`, `Access`, `Always Online`, `Analytics`, `Apps Marketplace`, `Argo Smart Routing`, `Audit Logs`, `Authoritative DNS`, `Billing`, `Bot Management`, `Bring Your Own IP (BYOIP)`, `Browser Isolation`, `CDN Cache Purge`, `CDN/Cache`, `Cache Reserve`, `Challenge Platform`, `Cloud Access Security Broker (CASB)`, `Community Site`, `DNS Root Servers`, `DNS Updates`, `Dashboard`, `Data Loss Prevention (DLP)`, `Developer's Site`, `Digital Experience Monitoring (DEX)`, `Distributed Web Gateway`, `Durable Objects`, `Email Routing`, `Ethereum Gateway`, `Firewall`, `Gateway`, `Geo-Key Manager`, `Image Resizing`, `Images`, `Infrastructure`, `Lists`, `Load Balancing and Monitoring`, `Logs`, `Magic Firewall`, `Magic Transit`, `Magic WAN`, `Magic WAN Connector`, `Marketing Site`, `Mirage`, `Network`, `Notifications`, `Observatory`, `Page Shield`, `Pages`, `R2`, `Radar`, `Randomness Beacon`, `Recursive DNS`, `Registrar`, `Registration Data Access Protocol (RDAP)`, `SSL Certificate Provisioning`, `SSL for SaaS Provisioning`, `Security Center`, `Snippets`, `Spectrum`, `Speed Optimizations`, `Stream`, `Support Site`, `Time Services`, `Trace`, `Tunnel`, `Turnstile`, `WARP`, `Waiting Room`, `Web Analytics`, `Workers`, `Workers KV`, `Workers Preview`, `Zaraz`, `Zero Trust`, `Zero Trust Dashboard`, `Zone Versioning`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#affected_components NotificationPolicy#affected_components}
    */
    readonly affectedComponents?: string[];
    /**
    * Filter on Points of Presence.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#airport_code NotificationPolicy#airport_code}
    */
    readonly airportCode?: string[];
    /**
    * Alert trigger preferences. Example: `slo`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#alert_trigger_preferences NotificationPolicy#alert_trigger_preferences}
    */
    readonly alertTriggerPreferences?: string[];
    /**
    * State of the pool to alert on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#enabled NotificationPolicy#enabled}
    */
    readonly enabled?: string[];
    /**
    * Environment of pages. Available values: `ENVIRONMENT_PREVIEW`, `ENVIRONMENT_PRODUCTION`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#environment NotificationPolicy#environment}
    */
    readonly environment?: string[];
    /**
    * Pages event to alert. Available values: `EVENT_DEPLOYMENT_STARTED`, `EVENT_DEPLOYMENT_FAILED`, `EVENT_DEPLOYMENT_SUCCESS`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#event NotificationPolicy#event}
    */
    readonly event?: string[];
    /**
    * Source configuration to alert on for pool or origin.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#event_source NotificationPolicy#event_source}
    */
    readonly eventSource?: string[];
    /**
    * Stream event type to alert on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#event_type NotificationPolicy#event_type}
    */
    readonly eventType?: string[];
    /**
    * Alert grouping.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#group_by NotificationPolicy#group_by}
    */
    readonly groupBy?: string[];
    /**
    * Identifier health check. Required when using `filters.0.status`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#health_check_id NotificationPolicy#health_check_id}
    */
    readonly healthCheckId?: string[];
    /**
    * The incident impact level that will trigger the dispatch of a notification. Available values: `INCIDENT_IMPACT_NONE`, `INCIDENT_IMPACT_MINOR`, `INCIDENT_IMPACT_MAJOR`, `INCIDENT_IMPACT_CRITICAL`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#incident_impact NotificationPolicy#incident_impact}
    */
    readonly incidentImpact?: string[];
    /**
    * Stream input id to alert on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#input_id NotificationPolicy#input_id}
    */
    readonly inputId?: string[];
    /**
    * A numerical limit. Example: `100`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#limit NotificationPolicy#limit}
    */
    readonly limit?: string[];
    /**
    * Megabits per second threshold for dos alert.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#megabits_per_second NotificationPolicy#megabits_per_second}
    */
    readonly megabitsPerSecond?: string[];
    /**
    * Health status to alert on for pool or origin.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#new_health NotificationPolicy#new_health}
    */
    readonly newHealth?: string[];
    /**
    * Tunnel health status to alert on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#new_status NotificationPolicy#new_status}
    */
    readonly newStatus?: string[];
    /**
    * Packets per second threshold for dos alert.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#packets_per_second NotificationPolicy#packets_per_second}
    */
    readonly packetsPerSecond?: string[];
    /**
    * Load balancer pool identifier.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#pool_id NotificationPolicy#pool_id}
    */
    readonly poolId?: string[];
    /**
    * Product name. Available values: `worker_requests`, `worker_durable_objects_requests`, `worker_durable_objects_duration`, `worker_durable_objects_data_transfer`, `worker_durable_objects_stored_data`, `worker_durable_objects_storage_deletes`, `worker_durable_objects_storage_writes`, `worker_durable_objects_storage_reads`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#product NotificationPolicy#product}
    */
    readonly product?: string[];
    /**
    * Identifier of pages project.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#project_id NotificationPolicy#project_id}
    */
    readonly projectId?: string[];
    /**
    * Protocol to alert on for dos.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#protocol NotificationPolicy#protocol}
    */
    readonly protocol?: string[];
    /**
    * Requests per second threshold for dos alert.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#requests_per_second NotificationPolicy#requests_per_second}
    */
    readonly requestsPerSecond?: string[];
    /**
    * Selectors for alert. Valid options depend on the alert type.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#selectors NotificationPolicy#selectors}
    */
    readonly selectors?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#services NotificationPolicy#services}
    */
    readonly services?: string[];
    /**
    * A numerical limit. Example: `99.9`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#slo NotificationPolicy#slo}
    */
    readonly slo?: string[];
    /**
    * Status to alert on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#status NotificationPolicy#status}
    */
    readonly status?: string[];
    /**
    * Target host to alert on for dos.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#target_hostname NotificationPolicy#target_hostname}
    */
    readonly targetHostname?: string[];
    /**
    * Target ip to alert on for dos in CIDR notation.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#target_ip NotificationPolicy#target_ip}
    */
    readonly targetIp?: string[];
    /**
    * Target domain to alert on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#target_zone_name NotificationPolicy#target_zone_name}
    */
    readonly targetZoneName?: string[];
    /**
    * Tunnel IDs to alert on.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#tunnel_id NotificationPolicy#tunnel_id}
    */
    readonly tunnelId?: string[];
    /**
    * Filter for alert.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#where NotificationPolicy#where}
    */
    readonly where?: string[];
    /**
    * A list of zone identifiers.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#zones NotificationPolicy#zones}
    */
    readonly zones?: string[];
}
export declare function notificationPolicyFiltersToTerraform(struct?: NotificationPolicyFiltersOutputReference | NotificationPolicyFilters): any;
export declare function notificationPolicyFiltersToHclTerraform(struct?: NotificationPolicyFiltersOutputReference | NotificationPolicyFilters): any;
export declare class NotificationPolicyFiltersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NotificationPolicyFilters | undefined;
    set internalValue(value: NotificationPolicyFilters | undefined);
    private _actions?;
    get actions(): string[];
    set actions(value: string[]);
    resetActions(): void;
    get actionsInput(): string[] | undefined;
    private _affectedComponents?;
    get affectedComponents(): string[];
    set affectedComponents(value: string[]);
    resetAffectedComponents(): void;
    get affectedComponentsInput(): string[] | undefined;
    private _airportCode?;
    get airportCode(): string[];
    set airportCode(value: string[]);
    resetAirportCode(): void;
    get airportCodeInput(): string[] | undefined;
    private _alertTriggerPreferences?;
    get alertTriggerPreferences(): string[];
    set alertTriggerPreferences(value: string[]);
    resetAlertTriggerPreferences(): void;
    get alertTriggerPreferencesInput(): string[] | undefined;
    private _enabled?;
    get enabled(): string[];
    set enabled(value: string[]);
    resetEnabled(): void;
    get enabledInput(): string[] | undefined;
    private _environment?;
    get environment(): string[];
    set environment(value: string[]);
    resetEnvironment(): void;
    get environmentInput(): string[] | undefined;
    private _event?;
    get event(): string[];
    set event(value: string[]);
    resetEvent(): void;
    get eventInput(): string[] | undefined;
    private _eventSource?;
    get eventSource(): string[];
    set eventSource(value: string[]);
    resetEventSource(): void;
    get eventSourceInput(): string[] | undefined;
    private _eventType?;
    get eventType(): string[];
    set eventType(value: string[]);
    resetEventType(): void;
    get eventTypeInput(): string[] | undefined;
    private _groupBy?;
    get groupBy(): string[];
    set groupBy(value: string[]);
    resetGroupBy(): void;
    get groupByInput(): string[] | undefined;
    private _healthCheckId?;
    get healthCheckId(): string[];
    set healthCheckId(value: string[]);
    resetHealthCheckId(): void;
    get healthCheckIdInput(): string[] | undefined;
    private _incidentImpact?;
    get incidentImpact(): string[];
    set incidentImpact(value: string[]);
    resetIncidentImpact(): void;
    get incidentImpactInput(): string[] | undefined;
    private _inputId?;
    get inputId(): string[];
    set inputId(value: string[]);
    resetInputId(): void;
    get inputIdInput(): string[] | undefined;
    private _limit?;
    get limit(): string[];
    set limit(value: string[]);
    resetLimit(): void;
    get limitInput(): string[] | undefined;
    private _megabitsPerSecond?;
    get megabitsPerSecond(): string[];
    set megabitsPerSecond(value: string[]);
    resetMegabitsPerSecond(): void;
    get megabitsPerSecondInput(): string[] | undefined;
    private _newHealth?;
    get newHealth(): string[];
    set newHealth(value: string[]);
    resetNewHealth(): void;
    get newHealthInput(): string[] | undefined;
    private _newStatus?;
    get newStatus(): string[];
    set newStatus(value: string[]);
    resetNewStatus(): void;
    get newStatusInput(): string[] | undefined;
    private _packetsPerSecond?;
    get packetsPerSecond(): string[];
    set packetsPerSecond(value: string[]);
    resetPacketsPerSecond(): void;
    get packetsPerSecondInput(): string[] | undefined;
    private _poolId?;
    get poolId(): string[];
    set poolId(value: string[]);
    resetPoolId(): void;
    get poolIdInput(): string[] | undefined;
    private _product?;
    get product(): string[];
    set product(value: string[]);
    resetProduct(): void;
    get productInput(): string[] | undefined;
    private _projectId?;
    get projectId(): string[];
    set projectId(value: string[]);
    resetProjectId(): void;
    get projectIdInput(): string[] | undefined;
    private _protocol?;
    get protocol(): string[];
    set protocol(value: string[]);
    resetProtocol(): void;
    get protocolInput(): string[] | undefined;
    private _requestsPerSecond?;
    get requestsPerSecond(): string[];
    set requestsPerSecond(value: string[]);
    resetRequestsPerSecond(): void;
    get requestsPerSecondInput(): string[] | undefined;
    private _selectors?;
    get selectors(): string[];
    set selectors(value: string[]);
    resetSelectors(): void;
    get selectorsInput(): string[] | undefined;
    private _services?;
    get services(): string[];
    set services(value: string[]);
    resetServices(): void;
    get servicesInput(): string[] | undefined;
    private _slo?;
    get slo(): string[];
    set slo(value: string[]);
    resetSlo(): void;
    get sloInput(): string[] | undefined;
    private _status?;
    get status(): string[];
    set status(value: string[]);
    resetStatus(): void;
    get statusInput(): string[] | undefined;
    private _targetHostname?;
    get targetHostname(): string[];
    set targetHostname(value: string[]);
    resetTargetHostname(): void;
    get targetHostnameInput(): string[] | undefined;
    private _targetIp?;
    get targetIp(): string[];
    set targetIp(value: string[]);
    resetTargetIp(): void;
    get targetIpInput(): string[] | undefined;
    private _targetZoneName?;
    get targetZoneName(): string[];
    set targetZoneName(value: string[]);
    resetTargetZoneName(): void;
    get targetZoneNameInput(): string[] | undefined;
    private _tunnelId?;
    get tunnelId(): string[];
    set tunnelId(value: string[]);
    resetTunnelId(): void;
    get tunnelIdInput(): string[] | undefined;
    private _where?;
    get where(): string[];
    set where(value: string[]);
    resetWhere(): void;
    get whereInput(): string[] | undefined;
    private _zones?;
    get zones(): string[];
    set zones(value: string[]);
    resetZones(): void;
    get zonesInput(): string[] | undefined;
}
export interface NotificationPolicyPagerdutyIntegration {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#id NotificationPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#name NotificationPolicy#name}
    */
    readonly name?: string;
}
export declare function notificationPolicyPagerdutyIntegrationToTerraform(struct?: NotificationPolicyPagerdutyIntegration | cdktf.IResolvable): any;
export declare function notificationPolicyPagerdutyIntegrationToHclTerraform(struct?: NotificationPolicyPagerdutyIntegration | cdktf.IResolvable): any;
export declare class NotificationPolicyPagerdutyIntegrationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NotificationPolicyPagerdutyIntegration | cdktf.IResolvable | undefined;
    set internalValue(value: NotificationPolicyPagerdutyIntegration | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
}
export declare class NotificationPolicyPagerdutyIntegrationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NotificationPolicyPagerdutyIntegration[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NotificationPolicyPagerdutyIntegrationOutputReference;
}
export interface NotificationPolicyWebhooksIntegration {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#id NotificationPolicy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#name NotificationPolicy#name}
    */
    readonly name?: string;
}
export declare function notificationPolicyWebhooksIntegrationToTerraform(struct?: NotificationPolicyWebhooksIntegration | cdktf.IResolvable): any;
export declare function notificationPolicyWebhooksIntegrationToHclTerraform(struct?: NotificationPolicyWebhooksIntegration | cdktf.IResolvable): any;
export declare class NotificationPolicyWebhooksIntegrationOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): NotificationPolicyWebhooksIntegration | cdktf.IResolvable | undefined;
    set internalValue(value: NotificationPolicyWebhooksIntegration | cdktf.IResolvable | undefined);
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    resetName(): void;
    get nameInput(): string | undefined;
}
export declare class NotificationPolicyWebhooksIntegrationList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: NotificationPolicyWebhooksIntegration[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): NotificationPolicyWebhooksIntegrationOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy cloudflare_notification_policy}
*/
export declare class NotificationPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_notification_policy";
    /**
    * Generates CDKTF code for importing a NotificationPolicy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NotificationPolicy to import
    * @param importFromId The id of the existing NotificationPolicy that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NotificationPolicy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/notification_policy cloudflare_notification_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NotificationPolicyConfig
    */
    constructor(scope: Construct, id: string, config: NotificationPolicyConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _alertType?;
    get alertType(): string;
    set alertType(value: string);
    get alertTypeInput(): string | undefined;
    get created(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get modified(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _emailIntegration;
    get emailIntegration(): NotificationPolicyEmailIntegrationList;
    putEmailIntegration(value: NotificationPolicyEmailIntegration[] | cdktf.IResolvable): void;
    resetEmailIntegration(): void;
    get emailIntegrationInput(): cdktf.IResolvable | NotificationPolicyEmailIntegration[] | undefined;
    private _filters;
    get filters(): NotificationPolicyFiltersOutputReference;
    putFilters(value: NotificationPolicyFilters): void;
    resetFilters(): void;
    get filtersInput(): NotificationPolicyFilters | undefined;
    private _pagerdutyIntegration;
    get pagerdutyIntegration(): NotificationPolicyPagerdutyIntegrationList;
    putPagerdutyIntegration(value: NotificationPolicyPagerdutyIntegration[] | cdktf.IResolvable): void;
    resetPagerdutyIntegration(): void;
    get pagerdutyIntegrationInput(): cdktf.IResolvable | NotificationPolicyPagerdutyIntegration[] | undefined;
    private _webhooksIntegration;
    get webhooksIntegration(): NotificationPolicyWebhooksIntegrationList;
    putWebhooksIntegration(value: NotificationPolicyWebhooksIntegration[] | cdktf.IResolvable): void;
    resetWebhooksIntegration(): void;
    get webhooksIntegrationInput(): cdktf.IResolvable | NotificationPolicyWebhooksIntegration[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
