/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface RiskBehaviorConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/risk_behavior#account_id RiskBehavior#account_id}
    */
    readonly accountId: string;
    /**
    * behavior block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/risk_behavior#behavior RiskBehavior#behavior}
    */
    readonly behavior?: RiskBehaviorBehavior[] | cdktf.IResolvable;
}
export interface RiskBehaviorBehavior {
    /**
    * Whether this risk behavior type is enabled.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/risk_behavior#enabled RiskBehavior#enabled}
    */
    readonly enabled: boolean | cdktf.IResolvable;
    /**
    * Name of this risk behavior type
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/risk_behavior#name RiskBehavior#name}
    */
    readonly name: string;
    /**
    * Risk level. Available values: `low`, `medium`, `high`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/risk_behavior#risk_level RiskBehavior#risk_level}
    */
    readonly riskLevel: string;
}
export declare function riskBehaviorBehaviorToTerraform(struct?: RiskBehaviorBehavior | cdktf.IResolvable): any;
export declare function riskBehaviorBehaviorToHclTerraform(struct?: RiskBehaviorBehavior | cdktf.IResolvable): any;
export declare class RiskBehaviorBehaviorOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): RiskBehaviorBehavior | cdktf.IResolvable | undefined;
    set internalValue(value: RiskBehaviorBehavior | cdktf.IResolvable | undefined);
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _riskLevel?;
    get riskLevel(): string;
    set riskLevel(value: string);
    get riskLevelInput(): string | undefined;
}
export declare class RiskBehaviorBehaviorList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: RiskBehaviorBehavior[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): RiskBehaviorBehaviorOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/risk_behavior cloudflare_risk_behavior}
*/
export declare class RiskBehavior extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_risk_behavior";
    /**
    * Generates CDKTF code for importing a RiskBehavior resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the RiskBehavior to import
    * @param importFromId The id of the existing RiskBehavior that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/risk_behavior#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the RiskBehavior to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.36.0/docs/resources/risk_behavior cloudflare_risk_behavior} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options RiskBehaviorConfig
    */
    constructor(scope: Construct, id: string, config: RiskBehaviorConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _behavior;
    get behavior(): RiskBehaviorBehaviorList;
    putBehavior(value: RiskBehaviorBehavior[] | cdktf.IResolvable): void;
    resetBehavior(): void;
    get behaviorInput(): cdktf.IResolvable | RiskBehaviorBehavior[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
